# twined

A library to help digital twins talk to one another. Read more at [twined.readthedocs.io](https://twined.readthedocs.io)

[![codecov](https://codecov.io/gh/octue/twined/branch/master/graph/badge.svg)](https://codecov.io/gh/octue/twined)
[![Documentation Status](https://readthedocs.org/projects/twined/badge/?version=latest)](https://twined.readthedocs.io/en/latest/?badge=latest)
 
